@@ -4,11 +4,8 @@
 import numpy as np
 import tensorflow as tf
 from bert4keras.backend import keras, K
-from bert4keras.backend import search_layer
 from bert4keras.backend import sequence_masking
-from bert4keras.backend import pool1d
-from bert4keras.backend import divisible_temporal_padding
-from bert4keras.snippets import is_string
+from bert4keras.backend import recompute_grad
 from keras import initializers, activations
 from keras.layers import *
 
@@ -139,7 +136,7 @@ class MultiHeadAttention(Layer):
         head_size,
         key_size=None,
         use_bias=True,
-        scaled_dot_product=True,
+        attention_scale=True,
         kernel_initializer='glorot_uniform',
         **kwargs
     ):
@@ -149,7 +146,7 @@ class MultiHeadAttention(Layer):
         self.out_dim = heads * head_size
         self.key_size = key_size or head_size
         self.use_bias = use_bias
-        self.scaled_dot_product = scaled_dot_product
+        self.attention_scale = attention_scale
         self.kernel_initializer = initializers.get(kernel_initializer)
 
     def build(self, input_shape):
@@ -175,6 +172,7 @@ class MultiHeadAttention(Layer):
             kernel_initializer=self.kernel_initializer
         )
 
+    @recompute_grad
     def call(self, inputs, mask=None, a_mask=None, p_bias=None):
         """实现多头注意力
         q_mask: 对输入的query序列的mask。
@@ -214,7 +212,7 @@ class MultiHeadAttention(Layer):
             pos_embeddings = K.permute_dimensions(inputs[n], (2, 0, 1))
             a = a + K.expand_dims(pos_embeddings, 0)
         # Attention（续）
-        if self.scaled_dot_product:
+        if self.attention_scale:
             a = a / self.key_size**0.5
         a = sequence_masking(a, v_mask, 1, -1)
         if a_mask is not None:
@@ -242,7 +240,7 @@ class MultiHeadAttention(Layer):
             'head_size': self.head_size,
             'key_size': self.key_size,
             'use_bias': self.use_bias,
-            'scaled_dot_product': self.scaled_dot_product,
+            'attention_scale': self.attention_scale,
             'kernel_initializer':
                 initializers.serialize(self.kernel_initializer),
         }
@@ -274,6 +272,16 @@ class LayerNormalization(Layer):
         self.hidden_initializer = initializers.get(hidden_initializer)
         self.epsilon = epsilon or 1e-12
 
+    def compute_mask(self, inputs, mask=None):
+        if self.conditional:
+            masks = [K.expand_dims(m, 0) for m in mask if m is not None]
+            if len(masks) == 0:
+                return None
+            else:
+                return K.all(K.concatenate(masks, axis=0), axis=0)
+        else:
+            return mask
+
     def build(self, input_shape):
         super(LayerNormalization, self).build(input_shape)
 
@@ -310,6 +318,7 @@ class LayerNormalization(Layer):
                     units=shape[0], use_bias=False, kernel_initializer='zeros'
                 )
 
+    @recompute_grad
     def call(self, inputs):
         """如果是条件Layer Norm，则默认以list为输入，第二个是condition
         """
@@ -582,6 +591,7 @@ class FeedForward(Layer):
             kernel_initializer=self.kernel_initializer
         )
 
+    @recompute_grad
     def call(self, inputs):
         x = inputs
         x = self.dense_1(x)
@@ -612,15 +622,17 @@ class ConditionalRandomField(Layer):
     def build(self, input_shape):
         super(ConditionalRandomField, self).build(input_shape)
         output_dim = input_shape[-1]
-        self.trans = self.add_weight(
+        self._trans = self.add_weight(
             name='trans',
             shape=(output_dim, output_dim),
             initializer='glorot_uniform',
             trainable=True
         )
         if self.lr_multiplier != 1:
-            K.set_value(self.trans, K.eval(self.trans) / self.lr_multiplier)
-            self.trans = self.lr_multiplier * self.trans
+            K.set_value(self._trans, K.eval(self._trans) / self.lr_multiplier)
+            self.trans = self.lr_multiplier * self._trans
+        else:
+            self.trans = self._trans
 
     def compute_mask(self, inputs, mask=None):
         return None
@@ -733,23 +745,28 @@ class MaximumEntropyMarkovModel(Layer):
         output_dim = input_shape[-1]
 
         if self.hidden_dim is None:
-            self.trans = self.add_weight(
+            self._trans = self.add_weight(
                 name='trans',
                 shape=(output_dim, output_dim),
                 initializer='glorot_uniform',
                 trainable=True
             )
             if self.lr_multiplier != 1:
-                K.set_value(self.trans, K.eval(self.trans) / self.lr_multiplier)
-                self.trans = self.lr_multiplier * self.trans
+                K.set_value(
+                    self._trans,
+                    K.eval(self._trans) / self.lr_multiplier
+                )
+                self.trans = self.lr_multiplier * self._trans
+            else:
+                self.trans = self._trans
         else:
-            self.l_trans = self.add_weight(
+            self._l_trans = self.add_weight(
                 name='l_trans',
                 shape=(output_dim, self.hidden_dim),
                 initializer='glorot_uniform',
                 trainable=True
             )
-            self.r_trans = self.add_weight(
+            self._r_trans = self.add_weight(
                 name='r_trans',
                 shape=(output_dim, self.hidden_dim),
                 initializer='glorot_uniform',
@@ -758,15 +775,17 @@ class MaximumEntropyMarkovModel(Layer):
 
             if self.lr_multiplier != 1:
                 K.set_value(
-                    self.l_trans,
-                    K.eval(self.l_trans) / self.lr_multiplier
+                    self._l_trans,
+                    K.eval(self._l_trans) / self.lr_multiplier
                 )
-                self.l_trans = self.lr_multiplier * self.l_trans
+                self.l_trans = self.lr_multiplier * self._l_trans
                 K.set_value(
-                    self.r_trans,
-                    K.eval(self.r_trans) / self.lr_multiplier
+                    self._r_trans,
+                    K.eval(self._r_trans) / self.lr_multiplier
                 )
-                self.r_trans = self.lr_multiplier * self.r_trans
+                self.r_trans = self.lr_multiplier * self._r_trans
+            else:
+                self.l_trans, self.r_trans = self._l_trans, self._r_trans
 
     def compute_mask(self, inputs, mask=None):
         return None
