@@ -218,7 +218,7 @@ class Transformer(object):
                 head_size = self.attention_head_size
                 key_size = self.attention_key_size
                 W = np.linalg.qr(np.random.randn(key_size, head_size))[0].T
-                if layer.scaled_dot_product:
+                if layer.attention_scale:
                     W = W * key_size**0.25 / head_size**0.25
                 for i in range(count):
                     w, v = weights[i], values[i]
@@ -357,7 +357,7 @@ class BERT(Transformer):
 
         attention_name = 'Transformer-%d-MultiHeadSelfAttention' % index
         feed_forward_name = 'Transformer-%d-FeedForward' % index
-        attention_mask = self.compute_attention_mask()
+        attention_mask = self.compute_attention_mask(index)
 
         # Self Attention
         xi, x, arguments = x, [x, x, x], {'a_mask': None}
@@ -609,7 +609,7 @@ class ALBERT(BERT):
 
         attention_name = 'Transformer-MultiHeadSelfAttention'
         feed_forward_name = 'Transformer-FeedForward'
-        attention_mask = self.compute_attention_mask(0)
+        attention_mask = self.compute_attention_mask(index)
 
         # Self Attention
         xi, x, arguments = x, [x, x, x], {'a_mask': None}
@@ -816,7 +816,7 @@ class NEZHA(BERT):
 
         attention_name = 'Transformer-%d-MultiHeadSelfAttention' % index
         feed_forward_name = 'Transformer-%d-FeedForward' % index
-        attention_mask = self.compute_attention_mask()
+        attention_mask = self.compute_attention_mask(index)
         position_bias = self.compute_position_bias(x)
 
         # Self Attention
@@ -1024,7 +1024,7 @@ class GPT2_ML(Transformer):
 
         attention_name = 'Transformer-%d-MultiHeadSelfAttention' % index
         feed_forward_name = 'Transformer-%d-FeedForward' % index
-        attention_mask = self.compute_attention_mask()
+        attention_mask = self.compute_attention_mask(index)
 
         # Self Attention
         xi, x, arguments = x, [x, x, x, attention_mask], {'a_mask': True}
@@ -1333,7 +1333,7 @@ class T5_Encoder(T5_Base):
 
         attention_name = 'Encoder-Transformer-%d-MultiHeadSelfAttention' % index
         feed_forward_name = 'Encoder-Transformer-%d-FeedForward' % index
-        attention_mask = self.compute_attention_mask()
+        attention_mask = self.compute_attention_mask(index)
         position_bias = self.compute_position_bias(x)
 
         # Self Attention
@@ -1357,7 +1357,7 @@ class T5_Encoder(T5_Base):
             head_size=self.attention_head_size,
             key_size=self.attention_key_size,
             use_bias=False,
-            scaled_dot_product=False,
+            attention_scale=False,
             kernel_initializer=self.initializer,
             name=attention_name
         )
@@ -1513,7 +1513,7 @@ class T5_Decoder(Transformer):
         self_attention_name = 'Decoder-Transformer-%d-MultiHeadSelfAttention' % index
         cross_attention_name = 'Decoder-Transformer-%d-MultiHeadCrossAttention' % index
         feed_forward_name = 'Decoder-Transformer-%d-FeedForward' % index
-        attention_mask = self.compute_attention_mask()
+        attention_mask = self.compute_attention_mask(index)
         position_bias = self.compute_position_bias([x, c])
 
         # Self Attention
@@ -1540,7 +1540,7 @@ class T5_Decoder(Transformer):
             head_size=self.attention_head_size,
             key_size=self.attention_key_size,
             use_bias=False,
-            scaled_dot_product=False,
+            attention_scale=False,
             kernel_initializer=self.initializer,
             name=self_attention_name
         )
@@ -1578,7 +1578,7 @@ class T5_Decoder(Transformer):
             head_size=self.attention_head_size,
             key_size=self.attention_key_size,
             use_bias=False,
-            scaled_dot_product=False,
+            attention_scale=False,
             kernel_initializer=self.initializer,
             name=cross_attention_name
         )
